// Function to generate a random hex color
function getRandomColor() {
    var letters = '0123456789ABCDEF';
    var color = '#';
    for (var i = 0; i < 6; i++) {
        color += letters[Math.floor(Math.random() * 16)];
    }
    return color;
}

// Function to generate a new color palette
function generatePalette() {
    var colorPalette = document.getElementById('colorPalette');
    colorPalette.innerHTML = ''; // Clear previous colors

    // Generate 5 random colors and display them
    for (var i = 0; i < 18; i++) {
        var colorBox = document.createElement('div');
        colorBox.className = 'colorBox';
        var color = getRandomColor();
        colorBox.style.backgroundColor = color;
        
        // Create text element for hex code
        var colorText = document.createElement('div');
        colorText.className = 'colorText';
        colorText.textContent = color;

        colorBox.appendChild(colorText);

        colorBox.addEventListener('click', function() {
            var color = this.style.backgroundColor;
            var hexColor = rgbToHex(color);
            
            // Copy hex color to clipboard
            navigator.clipboard.writeText(hexColor).then(function() {
                alert('Color copied to clipboard: ' + hexColor);
            }, function(err) {
                alert('Unable to copy color to clipboard', err);
            });
        });

        colorPalette.appendChild(colorBox);
    }
}

// Generate a palette when the page loads
generatePalette();

// Add event listener to the generate button
var generateButton = document.getElementById('generateButton');
generateButton.addEventListener('click', generatePalette);

// Function to convert rgb color to hex
function rgbToHex(rgb) {
    // Convert rgb color string to array of integers
    var parts = rgb.match(/^rgb\((\d+),\s*(\d+),\s*(\d+)\)$/);
    delete parts[0];
    for (var i = 1; i <= 3; ++i) {
        parts[i] = parseInt(parts[i]).toString(16);
        if (parts[i].length == 1) parts[i] = '0' + parts[i];
    }
    // Construct hex color
    var hexColor = '#' + parts.join('').toUpperCase();
    return hexColor;
}